// @flow

import React from 'react'
import { ThemeProvider } from 'react-css-themr'
import { Element } from 'react-scroll'
import Markdown from 'react-markdown'
import Hero from 'components/Hero'
import Template from 'components/Template'
import Section from 'components/Section'
import Card from 'components/Card'
import OptIn from 'components/OptIn'
import Gallery from 'components/Gallery'
import theme from './theme.yml'

import {
  optIn,
  navItems,
  sections,
  summary,
  images,
  heroBackground,
  services,
  places,
  languages,
  footer,
  copyright,
} from '../../sample-data/office.yml'

const Home = () => (
  <ThemeProvider theme={theme}>
    <Template
      theme={theme}
      items={navItems}
      languages={languages}
      footer={footer}
      copyright={copyright}
    >
      {/* Hero */}
      <Hero
        image={heroBackground}
        theme={{
          container: 'mw8 center dn flex-l items-center-l justify-center-l',
        }}
      >
        {/* OptIn appear in center hero in large mode */}
        <div className="-bg-navy ph5 pv3">
          <h1 className="white tc mb3 f3">{optIn.title}</h1>
          <h4 className="white tc f6 fw1 mb3">
            {optIn.subtitle}
          </h4>
          <OptIn
            requireName
            data={{
              isHorizontal: true,
              callToAction: optIn.callToAction,
            }}
          />
        </div>
      </Hero>
      {/* OptIn appear as a separate component in small mode */}
      <div className="dn-l w-100 -bg-navy pa2">
        <div className="mw7 center">
          <h1 className="white tc mb2 f3">{optIn.title}</h1>
          <h4 className="white tc f6 fw1 mb3">
            {optIn.subtitle}
          </h4>
          <OptIn
            requireName
            data={{
              isHorizontal: true,
              callToAction: optIn.callToAction,
            }}
          />
        </div>
      </div>
      <Element name="summary">
        <Section
          {...sections.summary}
          theme={{
            body: 'mw8 center',
          }}
        >
          <Markdown source={summary} />
        </Section>
      </Element>
      <Element name="services">
        <Section
          {...sections.services}
          theme={{
            body: 'mw8 center',
          }}
        >
          <div className="flex flex-wrap">
            {services.map(item => (
              <div key={item.title} className="w-100 w-third-ns pa2">
                <Card key={item.title} item={item} />
              </div>
            ))}
          </div>
        </Section>
      </Element>
      <Element name="places">
        <Section
          {...sections.places}
          theme={{
            body: 'mw8 center',
          }}
        >
          <div className="flex flex-wrap">
            {places.map(item => (
              <div key={item.title} className="w-100 w-50-m w-25-l pa2">
                <Card
                  key={item.title}
                  item={item}
                  theme={{
                    image: 'br3',
                    title: 'f4',
                  }}
                />
              </div>
            ))}
          </div>
        </Section>
      </Element>
      <Element name="gallery">
        <Section
          className="w-100"
          {...sections.gallery}
        >
          <Gallery
            className="w-100 flex flex-wrap"
            images={images}
          />
        </Section>
      </Element>
    </Template>
  </ThemeProvider>
)

export default Home
