// @flow

import React from 'react'
import { withState } from 'recompose'
import cn from 'classnames'
import { themr } from 'react-css-themr'
import Icon from 'components/Icon'

export const defaultStyles = {
  item: '',
  question: '',
  answer: '',
}

const FAQItem = withState('isOpen', 'open', false)(({
  item,
  isOpen,
  open,
  theme,
}: {
  item: {
    question: string,
    answer: string,
  },
  isOpen: boolean,
  open: (isOpen: boolean) => void,
  theme: { [key: string]: string },
}) => (
  <div
    data-component="FAQ"
    className={theme.item}
    onClick={() => open(!isOpen)}
  >
    <div className={cn('pointer flex items-center', theme.question)}>
      <Icon className={theme.icon} name={isOpen ? 'fa-minus' : 'fa-plus'} />
      {item.question}
    </div>
    {isOpen && (
      <div className={cn({ dn: !isOpen }, theme.answer)}>
        {item.answer}
      </div>
    )}
  </div>
))

FAQItem.defaultProps = {
  className: null,
}

const FAQ = ({
  items,
  theme,
  className,
}: {
  items: Array<{
    question: string,
    answer: string,
  }>,
  className?: string,
  theme: { [key: string]: string },
}) => (
  <div className={className}>
    {items.map(item => (
      <FAQItem key={item.question} theme={theme} item={item} />
    ))}
  </div>
)

FAQ.defaultProps = {
  className: null,
}

export default themr('FAQ', {}, { composeTheme: 'softly' })(FAQ)
