// @flow

import React from 'react'
import cn from 'classnames'
import { themr } from 'react-css-themr'
import { Form as BaseForm } from 'react-form'
import TextInput from 'components/TextInput'
import SelectInput from 'components/SelectInput'

export const defaultStyles = {
  header: '',
  input: 'input-reset outline-0',
  submit: '',
}

const Form = ({
  fields,
  submitText,
  validate,
  onSubmit,
  onValidationFail,
  showErrors,
  className,
  theme,
}: {
  fields: Array<FieldProps>,
  submitText?: string,
  validate: Function,
  onSubmit: Function,
  onValidationFail?: Function,
  showErrors?: boolean,
  className?: string,
  theme: { [key: string]: string },
}) => {
  const inputTheme = {
    root: theme.inputWrapper,
    icon: theme.icon,
    label: theme.label,
    input: theme.input,
  }
  return (
    <BaseForm
      data-component="Form"
      onSubmit={onSubmit}
      onValidationFail={(...args) => onValidationFail && onValidationFail(...args)}
      validate={validate}
    >
      {({ submitForm, getError }) => (
        <div className={cn(theme.root, className)}>
          <form
            className={theme.form}
            onSubmit={submitForm}
          >
            <div className={theme.body}>
              {fields.map(({ type, ...value }) => {
                if (type === 'select') {
                  return (
                    <SelectInput
                      key={value.field}
                      {...value}
                      theme={inputTheme}
                    />
                  )
                }
                return (
                  <TextInput
                    key={value.field}
                    type={type}
                    {...value}
                    theme={inputTheme}
                  />
                )
              })}
            </div>
            <div className={theme.submitWrapper}>
              <button className={theme.submit} type="submit">{submitText}</button>
            </div>
          </form>
          {showErrors && (
            <div className={theme.errorWrapper}>
              {fields.map(({ field }) => (
                <div
                  key={field}
                  className={theme.error}
                >
                  {getError(field)}
                </div>
              ))}
            </div>
          )}
        </div>
       )}
    </BaseForm>
  )
}

Form.defaultProps = {
  className: null,
  showErrors: false,
  submitText: 'Submit',
  onValidationFail: null,
}

export default themr('Form', {}, { composeTheme: 'softly' })(Form)
