// @flow

import React, { Component } from 'react'
import { compose } from 'recompose'
import withScriptjs from 'react-google-maps/lib/async/withScriptjs'
import {
  withGoogleMap,
  GoogleMap,
  Marker,
  DirectionsRenderer,
} from 'react-google-maps'
import SearchBox from 'react-google-maps/lib/places/SearchBox'
import { getPlace, getDirection } from './helpers'

const _Map = ({
  onMapLoad,
  onMapClick,
  onMarkerRightClick,
  center,
  routes,
  markers,
}: {
  onMapLoad: Function,
  onMapClick: Function,
  onMarkerRightClick: Function,
  center: any,
  directions: any,
  routes: Array<any>,
  markers: Array<any>,
}) => {
  // const defaultCenter = {
  //   lat: center.lat(),
  //   lng: center.lng(),
  // }
  // console.log({ defaultCenter })
  console.log(center)
  const defaultCenter = center || { lat: 10.7661204, lng: 106.6640309 }
  console.log(routes && routes[0])
  return (
    <GoogleMap
      ref={onMapLoad}
      defaultZoom={10}
      defaultCenter={defaultCenter}
      center={center}
      onClick={onMapClick}
    >
      <SearchBox
        // ref={onSearchBoxMounted}
        // bounds={bounds}
        controlPosition={window.google.maps.ControlPosition.TOP_LEFT}
        onPlacesChanged={console.log}
        inputPlaceholder="Customized your placeholder"
      />
      {markers && markers.map(marker => (
        <Marker
          {...marker}
          onRightClick={() => onMarkerRightClick(marker)}
        />
      ))}
      {routes && routes.map(directions => (
        <DirectionsRenderer directions={directions} />
      ))}
    </GoogleMap>
  )
}

const AsyncGettingStartedExampleGoogleMap = compose(
  withScriptjs,
  withGoogleMap,
)(_Map)

export default class AsyncGettingStartedExample extends Component {
  props: {
    originId: string,
    destinationIds: Array<string>,
  };

  state = {
    directions: null,
    markers: [{
      position: { lat: 10.7661204, lng: 106.6640309 },
      key: 'Taiwan',
      defaultAnimation: 2,
    }],
    // origin: { lat: 10.7661204, lng: 106.6640309 },
    // destination: { lat: 10.7710218, lng: 106.6810659 },
  };

  state: {
    origin?: any,
    routes?: any,
    desinations?: any,
  }

  async getInitData(): Promise<{
    origin: any,
    routes: Array<any>,
    destinations: Array<any>,
  }> {
    const { originId, destinationIds } = this.props
    const results = await getPlace(originId)
    const origin = {
      lat: results[0].geometry.location.lat(),
      lng: results[0].geometry.location.lng(),
    }
    const destinations = (await Promise.all(destinationIds.map(getPlace))).map(value => ({
      lat: value[0].geometry.location.lat(),
      lng: value[0].geometry.location.lng(),
    }))

    const routes = await Promise.all(
      destinations.map(destination => getDirection({ origin, destination })),
    )

    return {
      origin,
      routes,
      destinations,
    }
  }

  handleMapLoad = () => {
    this.getInitData()
      .then(({ origin, routes }) => {
        this.setState({
          origin,
          routes,
        })
      })
  }

  /*
   * This is called when you click on the map.
   * Go and try click now.
   */

   /*
  handleMapClick = (event: any) => {
    const nextMarkers = [
      ...this.state.markers,
      {
        position: event.latLng,
        defaultAnimation: 2,
        key: Date.now(),
      },
    ]
    this.setState({
      markers: nextMarkers,
    })

    const geocoder = new window.google.maps.Geocoder()
    // const placeId = 'ChIJz1DgnSEvdTER39rdX1SQ8NQ'
    // const place2Id = 'ChIJ5Y0kw-gudTERIqLMXlqtGCE'
    const place3Id = 'ChIJS6rgU5kvdTER0LlCXTU08GE'

    // const place3 = { lat: 10.7382142, lng: 106.7152543 }

    geocoder.geocode({ placeId: place3Id }, (results, status) => {
      if (status === 'OK') {
        const DirectionsService = new window.google.maps.DirectionsService()
        DirectionsService.route({
          origin: this.state.origin,
          destination: results[0].geometry.location,
          travelMode: window.google.maps.TravelMode.DRIVING,
        }, (result, _status) => {
          if (_status === window.google.maps.DirectionsStatus.OK) {
            console.log(result)
            this.setState({
              directions: result,
            })
          } else {
            console.error(`error fetching directions ${result}`)
          }
        })
      } else {
        window.alert(`Geocoder failed due to: ${status}`)
      }
    })
  }

  handleMarkerRightClick = (targetMarker: any) => {
    const nextMarkers = this.state.markers.filter(marker => marker !== targetMarker)
    this.setState({
      markers: nextMarkers,
    })
  }
  */

  render() {
    return (
      <AsyncGettingStartedExampleGoogleMap
        googleMapURL="https://maps.googleapis.com/maps/api/js?v=3.exp&libraries=geometry,drawing,places&key=AIzaSyA28KsfUooJBCwkwR-rBPu5uMwQ2g9U3LM"
        loadingElement={
          <div style={{ }}>
            <span
              style={{
                display: 'block',
                width: '80px',
                height: '80px',
                margin: '150px auto',
                animation: 'fa-spin 2s infinite linear',
              }}
            />
          </div>
        }
        containerElement={
          <div style={{ height: '100%' }} />
        }
        mapElement={
          <div style={{ height: '100%' }} />
        }
        center={this.state.origin}
        routes={this.state.routes}
        markers={[{ position: this.state.origin }]}
        onMapLoad={this.handleMapLoad}
        // onMapClick={this.handleMapClick}
        // onMarkerRightClick={this.handleMarkerRightClick}
      />
    )
  }
}
