// @flow

import React from 'react'
import merge from 'lodash.merge'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import ProgressiveImage from 'react-progressive-image'

export const defaultStyles = {
  root: 'aspect-ratio--3x4 aspect-ratio--4x3-m aspect-ratio--16x9-l',
  body: 'flex items-center justify-center',
}
const Hero = ({
  children,
  image,
  smallImage,
  videos,
  overlayColor,
  theme,
  overrideTheme,
}: {
  children?: any,
  image?: string,
  smallImage?: string,
  videos: Array<string>,
  overlayColor: string,
  theme: { [key: string]: string },
  overrideTheme: { [key: string]: string },
}) => {
  const _theme = merge(theme, overrideTheme)
  return (
    <div className={cn('relative w-100', _theme.root)}>
      {/* Split into 2 components for easier apply effect to background image  */}
      <ProgressiveImage src={image} placeholder={smallImage}>
        {src => (
          <div
            style={!image ? {} : {
              background: `linear-gradient(${overlayColor}, ${overlayColor}), url(${src})`,
            }}
            className={cn('absolute aspect-ratio--object cover')}
          />
        )}
      </ProgressiveImage>
      <div className={cn('absolute aspect-ratio--object overflow-y-hidden dn flex-l items-center-l')}>
        {videos.length > 0 && (
          <video
            className="z-0 w-100"
            playsInline
            autoPlay
            muted
            loop
            poster={image}
          >
            {videos.map(video => (
              <source key={video} src={video} type="video/mp4" />
            ))}
          </video>
        )}
      </div>
      <div className={cn('absolute aspect-ratio--object', _theme.container)}>
        {children}
      </div>
    </div>
  )
}

Hero.defaultProps = {
  overlayColor: 'rgba(0, 0, 0, 0)',
  image: null,
  smallImage: null,
}

Hero.defaultProps = {
  children: null,
  className: null,
  backgroundImage: null,
  overlayColor: 'rgba(0, 0, 0, 0)',
  videos: [],
}

export default themr('Hero', {}, { composeTheme: 'softly' })(Hero)
