// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'

export const defaultStyles = {
  root: '',
  imageWrapper: '',
  image: 'h2 w2 pa2',
  bodyWrapper: '',
  title: 'f5',
  description: '',
  footer: '',
  actionWrapper: '',
  action: '',
}

const HorizontalItem = ({
  item: { image, title, description, actions = [] },
  reverse,
  className,
  theme,
  Link,
}: {
  item: Item,
  reverse?: boolean,
  className?: string,
  theme: { [key: string]: string },
  Link: any,
}) => (
  <div className={cn('flex', theme.root, className, { 'flex-row-reverse': reverse })}>
    <div className={theme.imageWrapper}>
      <img className={cn('flex-none-ns', theme.image)} src={image} alt={title} />
    </div>
    <div className={theme.bodyWrapper}>
      <div className={theme.title}>{title}</div>
      <div className={theme.description}>{description}</div>
      <div className={theme.footer}>
        {actions.length > 0 && actions.map(action => (
          <div className={theme.actionWrapper}>
            <Link
              className={cn('button', theme.action, action.className)}
              to={action.href}
            >
              {action.label}
            </Link>
          </div>
        ))}
      </div>
    </div>
  </div>
)

HorizontalItem.defaultProps = {
  className: null,
  reverse: false,
}

export default themr('HorizontalItem', {}, { composeTheme: 'softly' })(HorizontalItem)
