// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import Icon from 'components/Icon'

export const defaultStyles = {
  root: 'flex items-center',
  icon: '',
  label: 'w4 tr pa1 b -blue',
  value: 'pa1',
}

const LabelValue = ({
  icon,
  label,
  value,
  className,
  theme,
  ...props
}: {
  icon?: string,
  label?: string,
  value: string,
  className?: string,
  theme: { [key: string]: string }
}) => (
  <div
    className={cn(theme.root, className)}
    {...props}
  >
    <div className={theme.label}>
      {!!icon && (
        <Icon key="icon" className={theme.icon} name={icon} />
      )}
      {label}
    </div>
    <div className={theme.value}>{value}</div>
  </div>
)

LabelValue.defaultProps = {
  className: undefined,
  icon: null,
  label: null,
}

export default themr('LabelValue', {}, { composeTheme: 'softly' })(LabelValue)
