// @flow

import React from 'react'
import cn from 'classnames'
import { compose, withState } from 'recompose'
import { Motion, spring } from 'react-motion'
import Icon from 'components/Icon'

const items = [
  'Hello World',
  'Commercial',
  'Business',
  'Residents',
  'About Us',
  'Contact Us',
]

const SlideNav = ({
  isShow,
  isShowChild,
  showChild,
  className,
}: {
  isShow: boolean,
  isShowChild: boolean,
  showChild: (isShowChild: boolean) => void,
  className?: string,
}) => (
  <div className={className}>
    <Motion
      defaultStyle={{ left: 100 }}
      style={{
        left: !isShow ? spring(100) : spring(0),
      }}
    >
      {({ left }) => (
        <div
          className={cn('absolute absolute--fill bg-white z-999', { dn: left === 100 })}
          style={{
            transform: `translate(${left}%, 0)`,
            // right: `${left}%`,
          }}
        >
          {items.map(item => (
            <div
              key={item}
              className="bb b--light-gray pa3 ttu gray f5 relative w-100"
              onClick={() => showChild(true)}
            >
              {item}
              <div className="absolute right-0 pr3 top-0 bottom-0 flex items-center">
                <Icon name="fa-arrow-right" />
              </div>
            </div>
          ))}
        </div>
      )}
    </Motion>
    <Motion
      defaultStyle={{ left: 100 }}
      style={{
        left: !isShowChild ? spring(100) : spring(0),
      }}
    >
      {({ left }) => (
        <div
          className="absolute absolute--fill bg-white z-9999"
          style={{
            transform: `translate(${left}%, 0)`,
            // right: `${left}%`,
          }}
        >
          <div className="bg-gray yellow pa3">
            <Icon
              name="fa-arrow-left"
              className="f4"
              onClick={() => showChild(false)}
            />
          </div>
          {items.map(item => (
            <div
              key={item}
              className="bb b--light-gray pa3 ttu gray f5"
              onClick={() => showChild(true)}
            >
              {item}
            </div>
          ))}
        </div>
      )}
    </Motion>
  </div>
)

SlideNav.defaultProps = {
  className: null,
}

const Nav = ({
  isShow,
  show,
  showChild,
}: {
  isShow: boolean,
  show: (isShow: boolean) => void,
  showChild: (isShowChild: boolean) => void,
}) => (
  <div className="flex-none bg-yellow flex items-center w-100 justify-between pv3 ph3">
    <Icon
      name={isShow ? 'fa-times' : 'fa-bars'}
      className="f3"
      onClick={() => {
        if (isShow) {
          show(false)
          showChild(false)
        } else {
          show(true)
        }
      }}
    />
    <Icon
      name="fa-user"
      className="f3"
    />
    <Icon
      name="fa-phone-square"
      className="f3"
    />
  </div>
)

const _NestedNavigation = ({
  isShow,
  show,
  isShowChild,
  showChild,
}: {
  isShow: boolean,
  show: (isShow: boolean) => void,
  isShowChild: boolean,
  showChild: (isShowChild: boolean) => void,
}) => (
  <div className={cn('fixed w-100', { 'vh-100 flex flex-column': isShow })}>
    <Nav
      isShow={isShow}
      show={show}
      showChild={showChild}
    />
    <SlideNav
      className={cn('relative', { 'flex-auto': isShow })}
      isShow={isShow}
      isShowChild={isShowChild}
      showChild={showChild}
    />
  </div>
)

const NestedNavigation = compose(
  withState('isShow', 'show', false),
  withState('isShowChild', 'showChild', false),
)(_NestedNavigation)

const App = () => (
  <div>
    <NestedNavigation />
    <div className="ph2 pb5" style={{ paddingTop: '4.5rem' }}>
      Hello
    </div>
  </div>
)

export default App
