// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'

export const defaultStyles = {
  root: '',
  title: '',
  subtitle: '',
  body: 'mw8 center',
}

const Section = ({
  title,
  subtitle,
  backgroundImage,
  overlayColor = 'rgba(0, 0, 0, 0)',
  titleEle = 'h3',
  subtitleEle = 'h4',
  showHr,
  children,
  theme,
  className,
  ...props
}: {
  title: string,
  subtitle?: string,
  backgroundImage?: string,
  overlayColor?: string,
  children?: any,
  titleEle?: any,
  subtitleEle?: any,
  showHr?: boolean,
  theme: { [key: string]: string },
  className?: string,
}) => {
  const style = backgroundImage ? {
    background: `linear-gradient(${overlayColor}, ${overlayColor}), url(${backgroundImage})`,
  } : {}
  const Header = titleEle
  const Subtitle = subtitleEle

  return (
    <section
      data-component="Section"
      className={cn(theme.root, className)}
      style={style}
      {...props}
    >
      <header className={theme.header}>
        <Header className={theme.title}>{title}</Header>
        {subtitle && (
          <Subtitle className={theme.subtitle}>{subtitle}</Subtitle>
        )}
      </header>
      {showHr && <div className={theme.hr} />}
      <div className={theme.body}>{children}</div>
    </section>
  )
}

Section.defaultProps = {
  subtitle: undefined,
  titleEle: 'h3',
  subtitleEle: 'h4',
  backgroundImage: undefined,
  overlayColor: 'rgba(0, 0, 0, 0)',
  showHr: false,
  children: null,
  className: undefined,
}

export default themr('Section', {}, { composeTheme: 'softly' })(Section)
