// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import { FormField } from 'react-form'
import Icon from 'components/Icon'

class SelectInput extends React.PureComponent {
  props: {
    field: string,
    type: string,
    multiline: boolean,
    icon: string,
    label?: string,
    className?: string,
    theme: { [key: string]: string},
    options: Array<{ value: string, label: string }>,
  };

  ref: any;

  static defaultProps = {
    className: undefined,
    label: undefined,
  }

  render() {
    const {
      field,
      options = [],
      icon,
      label,
      className,
      theme,
      ...rest
    } = this.props
    return (
      <FormField
        field={field}
        showErrors={false}
      >
        {({ setValue, getValue, setTouched }) => (
          <div className={cn(theme.root, className)} onClick={() => this.ref.focus()}>
            {!!label && (
              <label className={theme.label} htmlFor={field}>{label}</label>
            )}
            <div className="flex items-center">
              {!!icon && (
                <Icon key="icon" className={theme.icon} name={icon} />
              )}
              <select
                ref={(ref) => { this.ref = ref }}
                name={field}
                className={cn('flex-auto input-reset outline-0 bn', theme.input)}
                {...rest} // Send the rest of your props to React-Select
                value={getValue()} // Set the value to the forms value
                onChange={(e) => {
                  setValue(e.target.value)
                }} // On Change, update the form value
                onBlur={() => setTouched()}
              >
                {options.map(item => (
                  <option key={item.value} value={item.value}>{item.label}</option>
                ))}
              </select>
            </div>
          </div>
        )}
      </FormField>
    )
  }
}

export default themr('SelectInput', {}, { composeTheme: 'softly' })(SelectInput)
