// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import reduce from 'lodash.reduce'
import camelcase from 'camelcase'
import Section from 'components/Section'

export const defaultStyles = {
  root: '',
  leftTitle: '',
  leftSubtitle: '',
  leftBody: 'mw8 center',
  leftItemWrapper: 'w-100 w-third-ns pv2 ph2-ns',
  leftAction: '',
  rightTitle: '',
  rightSubtitle: '',
  rightBody: 'mw8 center',
  rightItemWrapper: 'w-100 w-third-ns pv2 ph2-ns',
  rightAction: '',
}

function getTheme(type: 'left' | 'right', theme: { [key: string]: string }) {
  return reduce(theme, (acc, value, key) => {
    if (key.startsWith(type)) {
      return {
        ...acc,
        [camelcase(key.replace(type, ''))]: value,
      }
    }
    return acc
  }, {})
}

const SplitSection = ({
  section: {
    left,
    right,
  },
  theme,
  childrenTheme,
  Link,
  className,
}: {
  section: {
    left: TSection,
    right: TSection,
  },
  theme: { [key: string]: string },
  childrenTheme: { [key: string]: string },
  Link: any,
  className?: string,
}) => {
  const leftTheme = getTheme('left', theme)
  const rightTheme = getTheme('right', theme)
  const leftChildrenTheme = getTheme('left', childrenTheme)
  const rightChildrenTheme = getTheme('right', childrenTheme)
  return (
    <div className={cn(className, theme.root)}>
      <Section
        theme={leftTheme}
        childrenTheme={leftChildrenTheme}
        section={left}
        Link={Link}
      />
      <Section
        theme={rightTheme}
        childrenTheme={rightChildrenTheme}
        section={right}
        Link={Link}
      />
    </div>
  )
}

SplitSection.defaultProps = {
  callToAction: null,
  className: null,
  section: {},
}

export default themr('SplitSection', {}, { composeTheme: 'softly' })(SplitSection)
