// @flow

import React from 'react'
import R from 'ramda'
import { themr } from 'react-css-themr'
import { Element } from 'react-scroll'
import Markdown from 'react-markdown'
import Section from 'components/Section'
import Tabs from 'components/Tabs'

const removeEmpty = R.pickBy(v => !!v)

const Ground = ({ data, theme }: {
  data: any,
  theme: { [key: string]: string },
}) => {
  const { element, title, subtitle, items } = data
  const section = (
    <Section
      title={title}
      subtitle={subtitle}
      theme={theme}
    >
      <Tabs
        items={items}
        theme={removeEmpty({
          tabWrapper: theme.tabWrapper,
          item: theme.tabItem,
          selected: theme.selectedTab,
          body: theme.tabBody,
        })}
        renderItem={item => (
          <div className={theme.tabBody}>
            <div className={theme.tabImage}>
              <img src={item.image} alt={item.title} />
            </div>
            <div className={theme.tabText}>
              <Markdown source={item.description} />
            </div>
          </div>
        )}
      />
    </Section>
  )

  if (!element) return section

  return (
    <Element name={element}>
      {section}
    </Element>
  )
}

export default themr('Ground', {}, { composeTheme: 'softly' })(Ground)
