// @flow

import React from 'react'
import R from 'ramda'
import { themr } from 'react-css-themr'
import { Element } from 'react-scroll'
import Section from 'components/Section'
import LabelValue from 'components/LabelValue'

const removeEmpty = R.pickBy(v => !!v)

const Payment = ({ data, theme }: {
  data: any,
  theme: { [key: string]: string },
}) => {
  const { element, title, subtitle, items } = data
  const section = (
    <Section
      title={title}
      subtitle={subtitle}
      theme={theme}
    >
      {items.map(({ label, value }) => (
        <LabelValue
          key={value}
          label={label}
          value={value}
          theme={removeEmpty({
            root: theme.item,
            icon: theme.itemIcon,
            label: theme.itemLabel,
            value: theme.itemValue,
          })}
        />
      ))}
    </Section>
  )

  if (!element) return section

  return (
    <Element name={element}>
      {section}
    </Element>
  )
}

export default themr('Payment', {}, { composeTheme: 'softly' })(Payment)
