// @flow

import React from 'react'
import R from 'ramda'
import { themr } from 'react-css-themr'
import { Element } from 'react-scroll'
import Section from 'components/Section'
import Carousel from 'components/Carousel'
import LabelValue from 'components/LabelValue'

const removeEmpty = R.pickBy(v => !!v)

const Summary = ({ data, theme }: {
  data: any,
  theme: { [key: string]: string }
}) => {
  const { element, title, subtitle, items, images } = data
  const section = (
    <Section
      title={title}
      subtitle={subtitle}
      theme={theme}
    >
      <div className={theme.textWrapper}>
        {items.map(({ label, value }) => (
          <LabelValue
            key={value}
            label={label}
            value={value}
            theme={removeEmpty({
              root: theme.item,
              icon: theme.itemIcon,
              label: theme.itemLabel,
              value: theme.itemValue,
            })}
          />
        ))}
      </div>
      <div className={theme.imageWrapper}>
        <Carousel
          className="w-100"
          imagesToShow={1}
          items={images}
          renderItem={({ src }) => (
            <div className="aspect-ratio--16x9" key={src}>
              <img
                className="absolute w-100"
                src={src}
                alt={src}
                onLoad={() => {
                  window.dispatchEvent(new Event('resize'))
                }}
              />
            </div>
          )}
        />
      </div>
    </Section>
  )

  if (!element) return section

  return (
    <Element name={element}>
      {section}
    </Element>
  )
}

export default themr('Summary', {}, { composeTheme: 'softly' })(Summary)
