'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactCssThemr = require('react-css-themr');

var _reactMarkdown = require('react-markdown');

var _reactMarkdown2 = _interopRequireDefault(_reactMarkdown);

var _recompose = require('recompose');

var _Icon = require('../Icon');

var _Icon2 = _interopRequireDefault(_Icon);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable react/no-array-index-key */

var _Item = function _Item(_ref) {
  var title = _ref.title,
      tooltip = _ref.tooltip,
      item = _ref.item,
      isHover = _ref.isHover,
      hover = _ref.hover,
      theme = _ref.theme;
  return _react2.default.createElement(
    'div',
    { className: (0, _classnames2.default)('relative', theme.item, { 'light-silver': item.enable === false }) },
    item.enable && _react2.default.createElement(_Icon2.default, { name: 'fa-check', className: 'mr2 green' }),
    item.enable === false && _react2.default.createElement(_Icon2.default, { name: 'fa-times', className: 'mr2 red' }),
    _react2.default.createElement(
      'span',
      { className: 'b' },
      item.value
    ),
    ' ',
    title,
    ' ',
    _react2.default.createElement(
      'span',
      {
        className: 'dib',
        onMouseOver: function onMouseOver() {
          return hover(true);
        },
        onMouseLeave: function onMouseLeave() {
          return hover(false);
        }
      },
      !!tooltip && _react2.default.createElement(_Icon2.default, { name: 'fa-info-circle', className: 'pa1 silver pointer f6' }),
      isHover && _react2.default.createElement(
        'div',
        {
          className: 'absolute bg-black-80 white br2 pv1 ph2 z-9999 left-0 f6',
          style: { left: 0, right: 0 }
        },
        _react2.default.createElement(_reactMarkdown2.default, { className: 'tooltip-markdown white-80', source: tooltip })
      )
    )
  );
};

_Item.defaultProps = {
  tooltip: null
};

var Item = (0, _recompose.withState)('isHover', 'hover', false)(_Item);

var PricingCard = function PricingCard(_ref2) {
  var className = _ref2.className,
      fields = _ref2.fields,
      item = _ref2.item,
      _ref2$theme = _ref2.theme,
      theme = _ref2$theme === undefined ? {} : _ref2$theme,
      renderLink = _ref2.renderLink;

  var finalTheme = Object.assign({}, theme, item.theme);
  return _react2.default.createElement(
    'div',
    { className: (0, _classnames2.default)(className, finalTheme.root) },
    _react2.default.createElement(
      'div',
      { className: finalTheme.name },
      item.name
    ),
    _react2.default.createElement(
      'div',
      { className: finalTheme.price },
      item.price
    ),
    _react2.default.createElement(
      'div',
      { className: finalTheme.body },
      fields.map(function (_ref3) {
        var key = _ref3.key,
            title = _ref3.title,
            tooltip = _ref3.tooltip;
        return _react2.default.createElement(Item, {
          key: key,
          item: item.items[key],
          title: title,
          tooltip: tooltip,
          theme: theme
        });
      })
    ),
    _react2.default.createElement(
      'div',
      { className: finalTheme.callToAction },
      !renderLink && _react2.default.createElement(
        'span',
        null,
        item.callToAction.label
      ),
      !!renderLink && renderLink(item.callToAction)
    )
  );
};

PricingCard.defaultProps = {
  className: null,
  renderLink: null
};

var PricingTable = function PricingTable(_ref4) {
  var className = _ref4.className,
      _ref4$data = _ref4.data,
      _ref4$data$fields = _ref4$data.fields,
      fields = _ref4$data$fields === undefined ? [] : _ref4$data$fields,
      data = _ref4$data.data,
      _ref4$theme = _ref4.theme,
      theme = _ref4$theme === undefined ? {} : _ref4$theme,
      renderLink = _ref4.renderLink;

  var keys = Object.keys(data);
  var itemTheme = {
    root: theme.itemRoot,
    name: theme.name,
    price: theme.price,
    body: theme.body,
    item: theme.item,
    callToAction: theme.callToAction
  };

  return _react2.default.createElement(
    'div',
    { className: (0, _classnames2.default)(className, theme.root) },
    _react2.default.createElement(
      'div',
      { className: 'flex flex-wrap' },
      keys.map(function (key) {
        return _react2.default.createElement(
          'div',
          { key: key, className: theme.itemWrapper },
          _react2.default.createElement(PricingCard, {
            theme: itemTheme,
            fields: fields,
            item: data[key],
            renderLink: renderLink
          })
        );
      })
    )
  );
};

PricingTable.defaultProps = {
  className: null,
  renderLink: null
};

exports.default = (0, _reactCssThemr.themr)('PricingTable', {}, { composeTheme: 'softly' })(PricingTable);